@@ -5,7 +5,7 @@ from typing import (
     Union,
     TYPE_CHECKING,
 )
-
+from io import BytesIO
 from pathlib import Path
 from PIL import (
     Image,
@@ -13,7 +13,7 @@ from PIL import (
 )
 
 from .base import (
-    Positioned,
+    Element,
     Drawer,
     ImageMode,
 )
@@ -21,17 +21,20 @@ from .canvas import Canvas
 from ..size import resize_image
 from ..context import ContextVar
 
-if TYPE_CHECKING:
+if TYPE_CHECKING:  # pragma: no cover
     from PIL.Image import Image as PillowImage
 
 
 class RectangleDrawer(Drawer):
     brightness: Optional[float]
-    background_image: Optional[Path]
+    background_image: Union[BytesIO, Path, None]
     background_color: Union[Tuple[int, int, int], Tuple[int, int, int, int]] = (255, 255, 255)
     alpha: Optional[int]
     _image_mode: ImageMode = ImageMode.RGBA
 
+    class Config:
+        arbitrary_types_allowed = True
+
     def draw(self, image: PillowImage) -> PillowImage:
         overlay_image = self.get_image()
         image.paste(overlay_image, self.start_point.to_tuple(), mask=overlay_image)
@@ -68,16 +71,23 @@ class RectangleDrawer(Drawer):
         return resize_image(image, self.size)
 
 
-class Rectangle(Positioned, Canvas):
+class Rectangle(Element, Canvas):
     _type: str = 'Rectangle'
     brightness: Union[float, ContextVar, None]
-    background_image: Union[Path, ContextVar, None]
+    background_image: Union[BytesIO, Path, ContextVar, None]
     background_color: Union[Tuple[int, int, int], Tuple[int, int, int, int], ContextVar] = (255, 255, 255)
     alpha: Union[int, ContextVar, None]
 
+    class Config:
+        arbitrary_types_allowed = True
+
     def create_drawer(self, canvas: PillowImage, context=None):
         data = self.collect_data(context)
-        start_point = self._get_start_point(self.size)
+        start_point = self._get_start_point(
+            data['horizontal_alignment'],
+            data['vertical_alignment'],
+            self.size,
+        )
 
         return RectangleDrawer(
             point=data['point'],
